@@ -100,6 +100,7 @@ def reset_constant(chemical, var, value):
 
 def reset_energy_constant(chemical, var, value):
     getfield = getattr
+    setattr(chemical, '_'+var, value)
     for handle in _energy_handles: 
         getfield(chemical, handle).set_value(var, value)
 
@@ -193,6 +194,18 @@ class Chemical:
             * SMILES (prefix with 'SMILES=' to ensure smiles parsing)
             * CAS number
     
+    Other Parameters
+    ----------------
+    search_ID=None : str
+        ID to search through database. Pass this key-word argument
+        when you'd like to give a custom name to the chemical, but
+        cannot find the chemical with that name.
+    eos : GCEOS subclass, optional
+        Equation of state class for solving thermodynamic properties.
+        Defaults to Peng-Robinson.
+    **data : float or str
+        User data (e.g. Tb, formula, etc.).
+    
     Examples
     --------
     Chemical objects contain pure component properties:
@@ -223,11 +236,11 @@ class Chemical:
              Pc: 2.2048e+07 Pa
              Vc: 5.6e-05 m^3/mol
              Hf: -2.4182e+05 J/mol
-             LHV: 0
-             HHV: 0
+             LHV: 44011 J/mol
+             HHV: 0 J/mol
              Hfus: 6010 J/mol
              omega: 0.344
-             dipole: None
+             dipole: 1.85 Debye
              similarity_variable: 0.16653
              iscyclic_aliphatic: 0
              combustion: {}
@@ -437,7 +450,7 @@ class Chemical:
         Heat of vaporization [J/mol]
     sigma(T) : 
         Surface tension [N/m].
-    epsilon : 
+    epsilon(T) : 
         Relative permitivity [-]
     S(phase, T, P) : 
         Entropy [J/mol].
@@ -484,7 +497,9 @@ class Chemical:
                 if ID in cache:
                     self = cache[ID]
                 else:
-                    cache[ID] = self = self.copy(ID=ID, CAS=self._CAS)                    
+                    cache[ID] = self = self.copy(ID=ID, CAS=self._CAS)
+            setfield = setattr
+            for i,j in data.items(): setfield(self, i, j)
         else:
             self = super().__new__(cls)
             self._ID = ID
@@ -572,21 +587,15 @@ class Chemical:
         for i in _energy_handles: setfield(self, i, None)
         if phase:
             for i in ('kappa', 'mu', 'V'):
-                handle = TPDependentModelHandle(i)
-                handle._chemical = self
-                setfield(self, '_' + i, handle)
+                setfield(self, '_' + i, TPDependentModelHandle(i))
             self._Cn = TDependentModelHandle('Cn')
         else:
             for i in ('kappa', 'mu', 'V'):
-                handle = PhaseTPHandle(i)
-                handle.s._chemical = handle.l._chemical = handle.g._chemical = self
-                setfield(self, '_' + i, handle)
+                setfield(self, '_' + i, PhaseTPHandle(i))
             self._Cn = Cn = PhaseTHandle('Cn')
             Cn.s._chemical = Cn.l._chemical = Cn.g._chemical = self
         for i in ('sigma', 'epsilon', 'Psat', 'Hvap'):
-            handle = TDependentModelHandle(i)
-            handle._chemical = self
-            setfield(self, '_' + i, handle)
+            setfield(self, '_' + i, TDependentModelHandle(i))
         self._locked_state = phase
         self._ID = ID
         self._phase_ref = phase_ref or phase
@@ -594,6 +603,7 @@ class Chemical:
         for i,j in data.items(): setfield(self, '_' + i , j)
         self._eos = create_eos(PR, self._Tc, self._Pc, self._omega)
         self._eos_1atm = self._eos.to_TP(298.15, 101325)
+        self._label_handles()
         if formula: self.formula = formula
         else: self._formula = formula
         return self
@@ -615,9 +625,22 @@ class Chemical:
                            new.Tb, new.eos, new.eos_1atm, new.phase_ref,
                            new._locked_state)
         cache[CAS] = new
+        new._label_handles()
         return new
     __copy__ = copy
 
+    def _label_handles(self):
+        handles = (self._Psat, self._Hvap, self._sigma, self._epsilon,
+                   self._V, self._Cn, self._mu, self._kappa)
+        isa = isinstance
+        for handle in handles:
+            if isa(handle, PhaseHandle):
+                handle.s._chemical = \
+                handle.l._chemical = \
+                handle.g._chemical = self
+            else:
+                handle._chemical = self
+
     def __reduce__(self):
         return unpickle_chemical, (get_chemical_data(self),)
     
@@ -1002,7 +1025,7 @@ class Chemical:
     
     @property
     def has_hydroxyl(self):
-        """Whether or not chemical contains a hydroxyl functional group,
+        """[bool] Whether or not chemical contains a hydroxyl functional group,
         as determined by the Dortmund/UNIFAC/PSRK functional groups."""
         for dct in (self._Dortmund, self._UNIFAC, self._PSRK):
             for n in (14, 15, 16, 81):
@@ -1236,7 +1259,7 @@ class Chemical:
         
         # Heat of vaporization
         data = (CAS, Tb, Tc, Pc, omega, similarity_variable, Psat, V)
-        self._Hvap = Hvap = heat_of_vaporization_handle(data)
+        self._Hvap = heat_of_vaporization_handle(data)
         
         # Viscosity
         ldata = (CAS, MW, Tm, Tc, Pc, Vc, omega, Psat, V.l)
@@ -1246,25 +1269,16 @@ class Chemical:
         # Conductivity
         ldata = (CAS, MW, Tm, Tb, Tc, Pc, omega)
         gdata = (CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, dipole, V.g, Cn.g, mu.g)
-        self._kappa = kappa = thermal_conductivity_handle(None, ldata, gdata)
+        self._kappa = thermal_conductivity_handle(None, ldata, gdata)
         
         # Surface tension
         data = (CAS, MW, Tb, Tc, Pc, Vc, Zc,
                 omega, self.Stiel_Polar)
-        self._sigma = sigma = surface_tension_handle(data)
+        self._sigma = surface_tension_handle(data)
         
         # Other
-        self._epsilon = epsilon = permitivity_handle((CAS, V.l,))
-        
-        for handle in (Psat, Hvap, sigma, epsilon):
-            handle._chemical = self
-        for phase_handle in (V, Cn): 
-            phase_handle.s._chemical = \
-            phase_handle.l._chemical = \
-            phase_handle.g._chemical = self
-        for phase_handel in (mu, kappa):
-            phase_handle.l._chemical = \
-            phase_handle.g._chemical = self
+        self._epsilon = permitivity_handle((CAS, V.l,))
+        self._label_handles()
         
         # self.delta = SolubilityParameter(self)
         # self.molecular_diameter = MolecularDiameter(self)
@@ -1373,6 +1387,9 @@ class Chemical:
                         S_int_Tm_to_T_ref_l = Cn_l.integrate_by_T_over_T(Tm, T_ref)
                     else:
                         H_int_Tm_to_T_ref_l = S_int_Tm_to_T_ref_l = None
+                else:
+                    H_int_Tm_to_T_ref_l = S_int_Tm_to_T_ref_l = \
+                    H_int_T_ref_to_Tb_l = S_int_T_ref_to_Tb_l = None
     
             # Excess data
             if isinstance(eos, GCEOS_DUMMY):
