@@ -86,10 +86,10 @@ def model_matching_function(f):
     raise ValueError('no available model matching signature')
 
 def thermo_model(evaluate,
-                 Tmin=None, Tmax=None,
+                 Tmin=None, Tmax=None, 
                  Pmin=None, Pmax=None,
                  name=None, var=None,
-                 **funcs):
+                 **kwargs):
     if not callable(evaluate):
         if Pmin or Pmax:
             ConstantModel = ConstantTPDependentModel
@@ -97,40 +97,21 @@ def thermo_model(evaluate,
             ConstantModel = ConstantTDependentModel
         else:
             ConstantModel = ConstantThermoModel
-        return ConstantModel(evaluate, Tmin, Tmax, Pmin, Pmax, name, var)
+        return ConstantModel(evaluate, Tmin, Tmax, Pmin, Pmax,
+                             name, var, **kwargs)
     Model = model_matching_function(evaluate)
-    return Model(evaluate, Tmin, Tmax, Pmin, Pmax, name, var, **funcs)
+    return Model(evaluate, Tmin, Tmax, Pmin, Pmax, name, var, **kwargs)
 
 
 # %% Thermo models
 
 class ThermoModel:
-    Tmin = Pmin = 0.0
-    Tmax = Pmax = infinity
-    
+    __slots__ = ()
     def __init_subclass__(cls, Functor=None):
         if Functor:
             REGISTERED_MODELS.append(cls)
             cls._Functor = Functor
     
-    def __init__(self, evaluate,
-                 Tmin=None, Tmax=None,
-                 Pmin=None, Pmax=None,
-                 name=None, var=None, **funcs):
-        self.__dict__ = funcs
-        self.name = name or functor_name(evaluate).replace('_', ' ')
-        self.var = var or evaluate.var
-        self.evaluate = evaluate
-        if Pmin: self.Pmin = Pmin
-        if Pmax: self.Pmax = Pmax
-        if Tmin: self.Tmin = Tmin
-        if Tmax: self.Tmax = Tmax
-    
-    def set_value(self, var, value):
-        isa = isinstance
-        for f in self.__dict__.values():
-            if isa(f, Functor): f.set_value(var, value)
-    
     def plot_vs_T(self, T_range=None, T_units=None, units=None, P=101325,
                   label_axis=True, **plot_kwargs):
         Ts, Ys = self.tabulate_vs_T(T_range, T_units, units, P)
@@ -159,6 +140,29 @@ class ThermoModel:
 
 
 class TDependentModel(ThermoModel, Functor=TFunctor):
+    __slots__ = ('name', 'var', 'evaluate', 'Pmin', 'Pmax', 'Tmin', 'Tmax',
+                 'integrate_by_T', 'integrate_by_T_over_T')
+    
+    def __init__(self, evaluate,
+                 Tmin=None, Tmax=None,
+                 Pmin=None, Pmax=None,
+                 name=None, var=None,
+                 integrate_by_T=None,
+                 integrate_by_T_over_T=None):
+        self.name = name or functor_name(evaluate).replace('_', ' ')
+        self.var = var or evaluate.var
+        self.evaluate = evaluate
+        self.Pmin = Pmin or 0.
+        self.Pmax = Pmax or infinity
+        self.Tmin = Tmin or 0.
+        self.Tmax = Tmax or infinity
+        self.integrate_by_T = integrate_by_T or self.numerically_integrate_by_T
+        self.integrate_by_T_over_T = integrate_by_T_over_T or self.numerically_integrate_by_T_over_T
+    
+    def set_value(self, var, value):
+        isa = isinstance
+        for f in (self.evaluate, self.integrate_by_T, self.integrate_by_T_over_T):
+            if isa(f, Functor): f.set_value(var, value)
     
     def tabulate_vs_T(self, T_range=None, T_units=None, units=None, P=101325):
         if not T_range: T_range = (self.Tmin, self.Tmax)
@@ -180,10 +184,10 @@ class TDependentModel(ThermoModel, Functor=TFunctor):
     def indomain(self, T, P=None):
         return self.Tmin < T < self.Tmax
     
-    def integrate_by_T(self, Ta, Tb, P=None):
+    def numerically_integrate_by_T(self, Ta, Tb, P=None):
         return self.evaluate((Tb+Ta)/2.)*(Tb - Ta)
     
-    def integrate_by_T_over_T(self, Ta, Tb, P=None): 
+    def numerically_integrate_by_T_over_T(self, Ta, Tb, P=None): 
         return self.evaluate((Tb+Ta)/2.)*log(Tb/Ta)
 
     def differentiate_by_T(self, T, P=None, dT=1e-12):
@@ -193,7 +197,7 @@ class TDependentModel(ThermoModel, Functor=TFunctor):
         return 0
     
     def integrate_by_P(self, Pa, Pb, T):
-        return (Pb - Pa) * self(T)
+        return (Pb - Pa) * self.evaulate(T)
     
     def show(self):
         print(f"{self}\n"
@@ -205,6 +209,9 @@ class TDependentModel(ThermoModel, Functor=TFunctor):
 
 
 class TPDependentModel(ThermoModel, Functor=TPFunctor):
+    __slots__ = TDependentModel.__slots__
+    __init__ = TDependentModel.__init__
+    set_value = TDependentModel.set_value
     
     def tabulate_vs_T(self, T_range=None, T_units=None, units=None, P=101325):
         if not T_range: T_range = (self.Tmin, self.Tmax)
@@ -225,10 +232,10 @@ class TPDependentModel(ThermoModel, Functor=TPFunctor):
     def indomain(self, T, P):
         return self.Tmin < T < self.Tmax and self.Pmin < P < self.Pmax
     
-    def integrate_by_T(self, Ta, Tb, P):
+    def numerically_integrate_by_T(self, Ta, Tb, P):
         return self.evaluate((Tb+Ta)/2, P)*(Tb - Ta)
     
-    def integrate_by_T_over_T(self, Ta, Tb, P): 
+    def numerically_integrate_by_T_over_T(self, Ta, Tb, P): 
         return self.evaluate((Tb+Ta)/2., P)*log(Tb/Ta)
     
     def integrate_by_P(self, Pa, Pb, T):
@@ -252,7 +259,7 @@ class TPDependentModel(ThermoModel, Functor=TPFunctor):
     
 
 class ConstantThermoModel(ThermoModel):
-    
+    __slots__ = ('value', 'name', 'var', 'Pmin', 'Pmax', 'Tmin', 'Tmax')
     def __init__(self, value, 
                  Tmin=None, Tmax=None,
                  Pmin=None, Pmax=None,
@@ -260,10 +267,12 @@ class ConstantThermoModel(ThermoModel):
         self.value = value
         self.name = name or "Constant"
         self.var = var
-        if Pmin: self.Pmin = Pmin
-        if Pmax: self.Pmax = Pmax
-        if Tmin: self.Tmin = Tmin
-        if Tmax: self.Tmax = Tmax
+        self.Pmin = Pmin or 0.
+        self.Pmax = Pmax or infinity
+        self.Tmin = Tmin or 0.
+        self.Tmax = Tmax or infinity
+
+    def set_value(self, var, value): pass
 
     def tabulate_vs_T(self, T_range=None, T_units=None, units=None, P=101325):
         if not T_range: T_range = (self.Tmin, self.Tmax)
@@ -323,6 +332,10 @@ class ConstantTPDependentModel(ConstantThermoModel):
 
 
 class InterpolatedTDependentModel(ThermoModel):
+    __slots__ = ('extrapolator', 'spline', 
+                 'Tmin', 'Tmax', 'T_lb', 'T_ub', 
+                 'name', 'var')
+    
     
     def __init__(self, Ts, Ys, Tmin=None, Tmax=None, 
                  kind='cubic', name='Interpolated', var=None):
@@ -330,8 +343,8 @@ class InterpolatedTDependentModel(ThermoModel):
         self.extrapolator = interp1d(Ts, Ys, fill_value='extrapolate')
         # If more than 5 property points, create a spline interpolation
         self.spline = interp1d(Ts, Ys, kind=kind) if len(Ts)>5 else self.extrapolator
-        if Tmin: self.Tmin = Tmin
-        if Tmax: self.Tmax = Tmax
+        self.Tmin = Tmin or 0.
+        self.Tmax = Tmax or infinity
         self.T_lb = Ts[0]
         self.T_ub = Ts[-1]
         self.name = name
@@ -340,11 +353,12 @@ class InterpolatedTDependentModel(ThermoModel):
     def evaluate(self, T, P=None):
         return self.spline(T) if (self.T_lb <= T <= self.T_ub) else self.extrapolator(T)
     
+    set_value = ConstantThermoModel.set_value
     tabulate_vs_T = TDependentModel.tabulate_vs_T
     tabulate_vs_P = TDependentModel.tabulate_vs_P
     indomain = TDependentModel.indomain
-    integrate_by_T = TDependentModel.integrate_by_T
-    integrate_by_T_over_T = TDependentModel.integrate_by_T_over_T
+    integrate_by_T = TDependentModel.numerically_integrate_by_T
+    integrate_by_T_over_T = TDependentModel.numerically_integrate_by_T_over_T
     integrate_by_P = TDependentModel.integrate_by_P
     differentiate_by_T = TDependentModel.differentiate_by_T
     differentiate_by_P = TDependentModel.differentiate_by_P
