@@ -179,7 +179,8 @@ class ThermoModelHandle:
     def add_model(self, evaluate=None,
                   Tmin=None, Tmax=None,
                   Pmin=None, Pmax=None,
-                  name=None, *, top_priority=False, **funcs):
+                  name=None, top_priority=False, 
+                  **kwargs):
         """
         Add model to handle.
 
@@ -199,27 +200,31 @@ class ThermoModelHandle:
             Name of the model. Defaults to function name.
         top_priority : int, optional
             Whether to add the model in 0th index/priority. The default is False.
-        **funcs : function
-            Other functions to give the model (e.g. integrate_by_T).
-
-        Note
-        ----
+        
+        Other Parameters
+        ----------------
+        integrate_by_T : function(Ta, Tb, ...)
+            Analytical integration function (to replace numerical integration).
+        integrate_by_T_over_T : function(Ta, Tb, ...)
+            Analytical integration function (to replace numerical integration).
+        
+        Notes
+        -----
         This method can be used as a function decorator, but the function is
-        not replace with model.
+        not replaced with the model.
 
         """
         if evaluate is None:
             return lambda evaluate: self.add_model(evaluate,
                                                    Tmin, Tmax,
                                                    Pmin, Pmax,
-                                                   name,
-                                                   top_priority=top_priority,
-                                                   **funcs)
+                                                   name, top_priority,
+                                                   **kwargs)
         if isinstance(evaluate, ThermoModel):
             model = evaluate
         else:
-            model = thermo_model(evaluate, Tmin, Tmax, Pmin,
-                                 Pmax, name, self._var, **funcs)
+            model = thermo_model(evaluate, Tmin, Tmax, Pmin, Pmax,
+                                 name, self._var, **kwargs)
         if top_priority:
             self._models.appendleft(model)
         else:
