@@ -4,14 +4,13 @@ Created on Sun Jul 21 22:15:30 2019
 
 @author: yoelr
 """
-
 from numpy import asarray, array
 from flexsolve import aitken_secant, IQ_interpolation
 from .solve_vle_composition import solve_x
-from ..utils import fill_like
+from ..utils import fill_like, Cache
 from .._settings import settings
 
-__all__ = ('DewPoint',)
+__all__ = ('DewPoint', 'DewPointCache')
 
 # %% Dew point values container
 
@@ -45,21 +44,20 @@ class DewPoint:
     Examples
     --------
     >>> import thermosteam as tmo
-    >>> import numpy as np
     >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
     >>> tmo.settings.set_thermo(chemicals)
     >>> DP = tmo.equilibrium.DewPoint(chemicals)
     >>> # Solve for dew point at constant temperautre
-    >>> molar_composition = np.array([0.5, 0.5])
+    >>> molar_composition = (0.5, 0.5)
     >>> dp = DP(z=molar_composition, T=355)
     >>> dp
-    DewPointValues(T=355, P=91970.14968399645, IDs=('Water', 'Ethanol'), z=[0.5 0.5], x=[0.851 0.149])
+    DewPointValues(T=355, P=91970.14968399647, IDs=('Water', 'Ethanol'), z=[0.5 0.5], x=[0.851 0.149])
     >>> # Note that the result is a DewPointValues object which contain all results as attibutes
     >>> (dp.T, dp.P, dp.IDs, dp.z, dp.x)
-    (355, 91970.14968399645, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.851, 0.149]))
+    (355, 91970.14968399647, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.851, 0.149]))
     >>> # Solve for dew point at constant pressure
     >>> DP(z=molar_composition, P=2*101324)
-    DewPointValues(T=376.2616600249249, P=202648, IDs=('Water', 'Ethanol'), z=[0.5 0.5], x=[0.832 0.168])
+    DewPointValues(T=376.2616600249248, P=202648, IDs=('Water', 'Ethanol'), z=[0.5 0.5], x=[0.832 0.168])
 
     """
     __slots__ = ('chemicals', 'phi', 'gamma', 'IDs',
@@ -91,7 +89,10 @@ class DewPoint:
         Psats = array([i if i > 1e-16 else 1e-16 for i in Psats])
         phi = self.phi(z_norm, T, P)
         x_gamma_pcf = phi * zP / Psats
-        self.x = solve_x(x_gamma_pcf, self.gamma, self.pcf, T, self.x)
+        try:
+            self.x = solve_x(x_gamma_pcf, self.gamma, self.pcf, T, self.x)
+        except:
+            self.x = solve_x(x_gamma_pcf, lambda *args: 1, self.pcf, T, self.x)
         return 1 - self.x.sum()
     
     def _P_error(self, P, T, z_norm, z_over_Psats):
@@ -100,6 +101,7 @@ class DewPoint:
         return 1 - self.x.sum()
     
     def __call__(self, z, *, T=None, P=None):
+        z = asarray(z, float)
         if T:
             if P: raise ValueError("may specify either T or P, not both")
             P, x = self.solve_Px(z, T)
@@ -115,7 +117,7 @@ class DewPoint:
 
         Parameters
         ----------
-        z : array_like
+        z : ndarray
             Molar composition.
         P : float
             Pressure [Pa].
@@ -134,11 +136,10 @@ class DewPoint:
         >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
         >>> tmo.settings.set_thermo(chemicals)
         >>> DP = tmo.equilibrium.DewPoint(chemicals)
-        >>> DP.solve_Tx(z=(0.5, 0.5), P=101325)
+        >>> DP.solve_Tx(z=np.array([0.5, 0.5]), P=101325)
         (357.4518474332522, array([0.849, 0.151]))
         
         """
-        z = asarray(z)
         z_norm = z/z.sum()
         zP = z * P
         args = (P, z_norm, zP)
@@ -165,7 +166,7 @@ class DewPoint:
 
         Parameters
         ----------
-        z : array_like
+        z : ndarray
             Molar composition.
         T : float
             Temperature (K).
@@ -174,7 +175,7 @@ class DewPoint:
         -------
         P : float
             Dew point pressure (Pa).
-        x : numpy.ndarray
+        x : ndarray
             Liquid phase molar composition.
 
         Examples
@@ -184,11 +185,10 @@ class DewPoint:
         >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
         >>> tmo.settings.set_thermo(chemicals)
         >>> DP = tmo.equilibrium.DewPoint(chemicals)
-        >>> DP.solve_Px(z=(0.5, 0.5), T=352.28)
-        (82444.298760479, array([0.853, 0.147]))
+        >>> DP.solve_Px(z=np.array([0.5, 0.5]), T=352.28)
+        (82444.29876047903, array([0.853, 0.147]))
  
        """
-        z = asarray(z)
         z_norm = z/z.sum()
         Psats = array([i(T) for i in self.Psats], dtype=float)
         z_over_Psats = z/Psats
@@ -208,4 +208,7 @@ class DewPoint:
     
     def __repr__(self):
         chemicals = ", ".join([i.ID for i in self.chemicals])
-        return f"{type(self).__name__}([{chemicals}])"
\ No newline at end of file
+        return f"{type(self).__name__}([{chemicals}])"
+    
+class DewPointCache(Cache): load = DewPoint
+del Cache
\ No newline at end of file
