@@ -83,7 +83,9 @@ class LLE:
                  '_imol', # [MaterialIndexer] Stores vapor and liquid molar data.
                  '_thermal_condition', # [ThermalCondition] T and P values are stored here.
 )
-    differential_evolution_options = {'seed': 0}
+    differential_evolution_options = {'seed': 0,
+                                      'popsize': 12,
+                                      'tol': 0.002}
     
     def __init__(self, imol, thermal_condition=None, thermo=None):
         self._load_thermo(thermo)
