@@ -56,7 +56,7 @@ from .dippr import DIPPR_EQ105
 # from .electrochem import _Laliberte_Density_ParametersDict, Laliberte_Density
 from ..base import (V, InterpolatedTDependentModel, 
                     TPDependentModel, TPDependentHandleBuilder,
-                    PhaseTPPropertyBuilder, ThermoModelHandle)
+                    PhaseTPHandleBuilder, ThermoModelHandle)
 
 __all__ = ('volume_handle',
            'Yen_Woods',
@@ -580,10 +580,6 @@ def volume_liquid_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc,
         _, MW, Tc_, rhoc, A, B, C, D = _VDI_PPDS_2[CAS]
         data = (Tc, rhoc, MW, A, B, C, D)
         add_model(VDI_PPDS.from_args(data), 0., Tc_)
-    if CAS in _CRC_inorg_l:
-        _, MW, rho, k, Tm, Tmax = _CRC_inorg_l[CAS]
-        data = (MW, rho, k, Tm)
-        add_model(CRC_Inorganic.from_args(data), Tm, Tmax)
     if CAS in _Perry_l:
         _, C1, C2, C3, C4, Tmin, Tmax = _Perry_l[CAS]
         data = (C1, C2, C3, C4, True)
@@ -593,6 +589,13 @@ def volume_liquid_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc,
         model = InterpolatedTDependentModel(Ts, Vls,
                                             Tmin=Ts[0], Tmax=Ts[-1])
         add_model(model)
+    data = (Tb, Tc, Pc, MW, dipole, has_hydroxyl)
+    if all_([i is not None for i in data]):
+        add_model(Campbell_Thodos.from_args(data), 0, Tc)
+    if CAS in _CRC_inorg_l:
+        _, MW, rho, k, Tm, Tmax = _CRC_inorg_l[CAS]
+        data = (MW, rho, k, Tm)
+        add_model(CRC_Inorganic.from_args(data), Tm, Tmax)
     data = (Tc, Vc, Zc)
     if all_(data):
         add_model(Yen_Woods.from_args(data))
@@ -610,8 +613,6 @@ def volume_liquid_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc,
             SNM0_delta_SRK = float(_SNM0.at[CAS, 'delta_SRK'])
             data = (Tc, Vc, omega, SNM0_delta_SRK)
             add_model(SNM0.from_args(data))
-        else:
-            add_model(SNM0.from_args(data), 0, Tc)
     if CAS in _CRC_inorg_l_const:
         Vl = float(_CRC_inorg_l_const.at[CAS, 'Vm'])
         add_model(Vl, Tmin, Tmax, name="CRC inorganic liquid constant")
@@ -624,10 +625,6 @@ def volume_liquid_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc,
     data = (Tc, Vc, omega)
     if all_(data) and CAS in _COSTALD:
         add_model(Costald.from_args(data), 0, Tc)
-    data = (Tb, Tc, Pc, MW, dipole, has_hydroxyl)
-    if all_([i is not None for i in data]):
-        top_priority = bool(dipole)
-        add_model(Campbell_Thodos.from_args(data), 0, Tc, top_priority=top_priority)
     data = (Tc, Pc, omega)
     if all_(data):
         data = (Psat, Tc, Pc, omega, handle)
@@ -715,7 +712,7 @@ def volume_solid_handle(handle, CAS):
         handle.add_model(CRC_INORG_S_Vm, 0, 1e6, 0, 1e12)
 
 
-volume_handle = PhaseTPPropertyBuilder('V',
+volume_handle = PhaseTPHandleBuilder('V',
                                        volume_solid_handle, 
                                        volume_liquid_handle,
                                        volume_gas_handle)
